"""List strategies in serializable format."""


STRATEGIES = [
    {
        "tag": "IVY",
        "name": "Ivy",
        "riskAssets": ["VTI", "VEU", "VNQ", "AGG", "DBC"],
        "safeAssets": ["BIL"],
        "weights": [0.2, 0.2, 0.2, 0.2, 0.2],
        "frequency": "M",
    },
    {
        "tag": "RAAB",
        "name": "Robust Asset Allocation Balanced",
        "riskAssets": ["VNQ", "IEF", "DBC", "MTUM", "IWD", "EFA", "EFV"],
        "safeAssets": ["BIL"],
        "weights": [0.15, 0.2, 0.2, 0.2, 0.1, 0.1, 0.1],
        "frequency": "M",
    },
    {
        "tag": "DGDM",
        "name": "Diversified GEM Dual Momentum",
        "riskAssets": ["SPY", "AGG", "EFA"],
        "weights": [0.43, 0.3, 0.27],
        "frequency": "M",
    },
    {
        "tag": "VAAG12",
        "name": "Vigilant Asset Allocation G12",
        "riskAssets": [
            "SPY",
            "IWM",
            "QQQ",
            "VGK",
            "EWJ",
            "EEM",
            "VNQ",
            "DBC",
            "GLD",
            "TLT",
            "LQD",
            "HYG",
        ],
        "safeAssets": ["IEF", "LQD", "BIL"],
        "frequency": "M",
    },
    {
        "tag": "VAAG4",
        "name": "Vigilant Asset Allocation G4",
        "riskAssets": ["SPY", "EFA", "EEM", "AGG"],
        "safeAssets": ["LQD", "IEF", "BIL"],
        "frequency": "M",
    },
    {
        "tag": "KDAAA",
        "name": "Kipnis Defensive Adaptive Asset Allocation",
        "riskAssets": [
            "SPY",
            "VGK",
            "EWJ",
            "EEM",
            "VNQ",
            "RWX",
            "IEF",
            "TLT",
            "DBC",
            "GLD",
        ],
        "safeAssets": ["IEF"],
        "canaryAssets": ["EEM", "AGG"],
        "frequency": "M",
    },
    {
        "tag": "GPM",
        "name": "Generalized Protective Momentum",
        "riskAssets": [
            "SPY",
            "QQQ",
            "IWM",
            "VGK",
            "EWJ",
            "EEM",
            "VNQ",
            "DBC",
            "GLD",
            "HYG",
            "LQD",
        ],
        "safeAssets": ["BIL", "IEF"],
        "frequency": "M",
    },
    {
        "tag": "TIOF",
        "name": "Trend is Our Friend",
        "riskAssets": ["SPY", "AGG", "DBC", "VNQ"],
        "safeAssets": ["BIL"],
        "frequency": "M",
    },
    {
        "tag": "GTAA",
        "name": "Global Tactical Asset Allocation",
        "riskAssets": [
            "IWD",
            "MTUM",
            "IWN",
            "DWAS",
            "EFA",
            "EEM",
            "IEF",
            "BWX",
            "LQD",
            "TLT",
            "DBC",
            "GLD",
            "VNQ",
        ],
        "safeAssets": ["BIL"],
        "weights": [
            0.05,
            0.05,
            0.05,
            0.05,
            0.1,
            0.1,
            0.05,
            0.05,
            0.05,
            0.05,
            0.1,
            0.1,
            0.2,
        ],
        "frequency": "M",
    },
    {
        "tag": "DAA",
        "name": "Defensive Asset Allocation",
        "riskAssets": [
            "SPY",
            "QQQ",
            "VGK",
            "EWJ",
            "EEM",
            "VNQ",
            "IWM",
            "DBC",
            "TLT",
            "HYG",
            "TLT",
            "LQD",
            "GLD",
        ],
        "safeAssets": ["SHY", "IEF", "LQD"],
        "canaryAssets": ["EEM", "AGG"],
        "frequency": "M",
    },
    {
        "tag": "PAA",
        "name": "Protective Asset Allocation",
        "riskAssets": [
            "IEF",
            "IWM",
            "QQQ",
            "VNQ",
            "SPY",
            "VGK",
            "EEM",
            "EWJ",
            "DBC",
            "TLT",
            "GLD",
            "HYG",
            "LQD",
        ],
        "safeAssets": ["IEF"],
        "weights": [
            0.51,
            0.06,
            0.06,
            0.05,
            0.05,
            0.05,
            0.05,
            0.04,
            0.03,
            0.03,
            0.03,
            0.02,
            0.02,
        ],
        "frequency": "M",
    },
    {
        "tag": "AAA",
        "name": "Adaptive Asset Allocation",
        "riskAssets": [
            "IEF",
            "SPY",
            "VNQ",
            "RWX",
            "DBC",
            "EEM",
            "VGK",
            "TLT",
            "GLD",
            "EWJ",
        ],
        "weights": [0.3, 0.17, 0.1, 0.08, 0.07, 0.07, 0.06, 0.06, 0.05, 0.04],
        "frequency": "M",
    },
    {
        "tag": "GDM",
        "name": "GEM Dual Momentum",
        "riskAssets": ["SPY", "AGG", "EFA"],
        "canaryAssets": ["BIL"],
        "frequency": "M",
    },
    {
        "tag": "QSF",
        "name": "Quint Switching Filtered",
        "riskAssets": ["QQQ", "EEM", "EFA", "TLT", "SPY"],
        "safeAssets": ["IEF"],
        "frequency": "M",
    },
    {
        "tag": "CDM",
        "name": "Composite Dual Momentum",
        "riskAssets": ["SPY", "EFA", "HYG", "LQD", "VNQ", "REM", "GLD", "TLT"],
        "assetClasses": [
            "Equity",
            "Equity",
            "Bonds",
            "Bonds",
            "Real Estate",
            "Real Estate",
            "Stress",
            "Stress",
        ],
        "safeAssets": ["BIL"],
        "frequency": "M",
    },
    {
        "tag": "HMMRS",
        "name": "HMM Regime Switching",
        "riskAssets": [],
        "safeAssets": [],
        "frequency": "M",
    },
    {
        "tag": "RDSAA",
        "name": "Robeco Dynamic Strategic Asset Allocation",
        "riskAssets": ["VV", "IEF", "VB", "LQD", "DBC"],
        "weights": [0.25, 0.25, 0.05, 0.05, 0.05],
        "frequency": "M",
    },
]


VALID_CURRENCIES = (
    "AFN",
    "EUR",
    "ALL",
    "DZD",
    "USD",
    "EUR",
    "AOA",
    "XCD",
    "XCD",
    "ARS",
    "AMD",
    "AWG",
    "AUD",
    "EUR",
    "AZN",
    "BSD",
    "BHD",
    "BDT",
    "BBD",
    "BYN",
    "EUR",
    "BZD",
    "XOF",
    "BMD",
    "INR",
    "BTN",
    "BOB",
    "BOV",
    "USD",
    "BAM",
    "BWP",
    "NOK",
    "BRL",
    "USD",
    "BND",
    "BGN",
    "XOF",
    "BIF",
    "CVE",
    "KHR",
    "XAF",
    "CAD",
    "KYD",
    "XAF",
    "XAF",
    "CLP",
    "CLF",
    "CNY",
    "AUD",
    "AUD",
    "COP",
    "COU",
    "KMF",
    "CDF",
    "XAF",
    "NZD",
    "CRC",
    "XOF",
    "HRK",
    "CUP",
    "CUC",
    "ANG",
    "EUR",
    "CZK",
    "DKK",
    "DJF",
    "XCD",
    "DOP",
    "USD",
    "EGP",
    "SVC",
    "USD",
    "XAF",
    "ERN",
    "EUR",
    "SZL",
    "ETB",
    "EUR",
    "FKP",
    "DKK",
    "FJD",
    "EUR",
    "EUR",
    "EUR",
    "XPF",
    "EUR",
    "XAF",
    "GMD",
    "GEL",
    "EUR",
    "GHS",
    "GIP",
    "EUR",
    "DKK",
    "XCD",
    "EUR",
    "USD",
    "GTQ",
    "GBP",
    "GNF",
    "XOF",
    "GYD",
    "HTG",
    "USD",
    "AUD",
    "EUR",
    "HNL",
    "HKD",
    "HUF",
    "ISK",
    "INR",
    "IDR",
    "XDR",
    "IRR",
    "IQD",
    "EUR",
    "GBP",
    "ILS",
    "EUR",
    "JMD",
    "JPY",
    "GBP",
    "JOD",
    "KZT",
    "KES",
    "AUD",
    "KPW",
    "KRW",
    "KWD",
    "KGS",
    "LAK",
    "EUR",
    "LBP",
    "LSL",
    "ZAR",
    "LRD",
    "LYD",
    "CHF",
    "EUR",
    "EUR",
    "MOP",
    "MKD",
    "MGA",
    "MWK",
    "MYR",
    "MVR",
    "XOF",
    "EUR",
    "USD",
    "EUR",
    "MRU",
    "MUR",
    "EUR",
    "XUA",
    "MXN",
    "MXV",
    "USD",
    "MDL",
    "EUR",
    "MNT",
    "EUR",
    "XCD",
    "MAD",
    "MZN",
    "MMK",
    "NAD",
    "ZAR",
    "AUD",
    "NPR",
    "EUR",
    "XPF",
    "NZD",
    "NIO",
    "XOF",
    "NGN",
    "NZD",
    "AUD",
    "USD",
    "NOK",
    "OMR",
    "PKR",
    "USD",
    "PAB",
    "USD",
    "PGK",
    "PYG",
    "PEN",
    "PHP",
    "NZD",
    "PLN",
    "EUR",
    "USD",
    "QAR",
    "EUR",
    "RON",
    "RUB",
    "RWF",
    "EUR",
    "SHP",
    "XCD",
    "XCD",
    "EUR",
    "EUR",
    "XCD",
    "WST",
    "EUR",
    "STN",
    "SAR",
    "XOF",
    "RSD",
    "SCR",
    "SLL",
    "SGD",
    "ANG",
    "XSU",
    "EUR",
    "EUR",
    "SBD",
    "SOS",
    "ZAR",
    "SSP",
    "EUR",
    "LKR",
    "SDG",
    "SRD",
    "NOK",
    "SEK",
    "CHF",
    "CHE",
    "CHW",
    "SYP",
    "TWD",
    "TJS",
    "TZS",
    "THB",
    "USD",
    "XOF",
    "NZD",
    "TOP",
    "TTD",
    "TND",
    "TRY",
    "TMT",
    "USD",
    "AUD",
    "UGX",
    "UAH",
    "AED",
    "GBP",
    "USD",
    "USD",
    "USN",
    "UYU",
    "UYI",
    "UYW",
    "UZS",
    "VUV",
    "VES",
    "VND",
    "USD",
    "USD",
    "XPF",
    "MAD",
    "YER",
    "ZMW",
    "ZWL",
    "XBA",
    "XBB",
    "XBC",
    "XBD",
    "XTS",
    "XXX",
    "XAU",
    "XPD",
    "XPT",
    "XAG",
    "AFA",
    "FIM",
    "ALK",
    "ADP",
    "ESP",
    "FRF",
    "AOK",
    "AON",
    "AOR",
    "ARA",
    "ARP",
    "ARY",
    "RUR",
    "ATS",
    "AYM",
    "AZM",
    "RUR",
    "BYB",
    "BYR",
    "RUR",
    "BEC",
    "BEF",
    "BEL",
    "BOP",
    "BAD",
    "BRB",
    "BRC",
    "BRE",
    "BRN",
    "BRR",
    "BGJ",
    "BGK",
    "BGL",
    "BUK",
    "HRD",
    "HRK",
    "CYP",
    "CSJ",
    "CSK",
    "ECS",
    "ECV",
    "GQE",
    "EEK",
    "XEU",
    "FIM",
    "FRF",
    "FRF",
    "FRF",
    "GEK",
    "RUR",
    "DDM",
    "DEM",
    "GHC",
    "GHP",
    "GRD",
    "FRF",
    "GNE",
    "GNS",
    "GWE",
    "GWP",
    "ITL",
    "ISJ",
    "IEP",
    "ILP",
    "ILR",
    "ITL",
    "RUR",
    "RUR",
    "LAJ",
    "LVL",
    "LVR",
    "LSM",
    "ZAL",
    "LTL",
    "LTT",
    "LUC",
    "LUF",
    "LUL",
    "MGF",
    "MWK",
    "MVQ",
    "MLF",
    "MTL",
    "MTP",
    "FRF",
    "MRO",
    "FRF",
    "MXP",
    "RUR",
    "FRF",
    "MZE",
    "MZM",
    "NLG",
    "ANG",
    "NIC",
    "PEH",
    "PEI",
    "PEN",
    "PES",
    "PLZ",
    "PTE",
    "FRF",
    "ROK",
    "ROL",
    "RON",
    "RUR",
    "FRF",
    "FRF",
    "FRF",
    "ITL",
    "STD",
    "CSD",
    "EUR",
    "SKK",
    "SIT",
    "ZAL",
    "SDG",
    "RHD",
    "ESA",
    "ESB",
    "ESP",
    "SDD",
    "SDP",
    "SRG",
    "SZL",
    "CHC",
    "RUR",
    "TJR",
    "IDR",
    "TPE",
    "TRL",
    "TRY",
    "RUR",
    "TMM",
    "UGS",
    "UGW",
    "UAK",
    "SUR",
    "USS",
    "UYN",
    "UYP",
    "RUR",
    "VEB",
    "VEF",
    "VEF",
    "VEF",
    "VNC",
    "YDD",
    "YUD",
    "YUM",
    "YUN",
    "ZRN",
    "ZRZ",
    "ZMK",
    "ZWC",
    "ZWD",
    "ZWD",
    "ZWN",
    "ZWR",
    "XFO",
    "XRE",
    "XFU",
)
